@@ -1,19 +1,23 @@
-# Copyright (c) 2015 Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2015, 2020, Oracle and/or its affiliates.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import os
 
@@ -229,16 +233,16 @@ class SourceRDBMS:
 
 class SourceRDBMSMssql(SourceRDBMS):
     def get_copy_table_cmd(self, table, connection_args):
-        return 'bcp "SELECT %(select_expression)s FROM %(unquoted_source_schema)s.%(unquoted_source_table)s" queryout %(source_table)s.csv -c -t, -T -S .\%(source_instance)s -U %(source_user)s -P %%arg_source_passwords' % dict(table.items() + connection_args.items())
+        return 'bcp "SELECT %(select_expression)s FROM %(unquoted_source_schema)s.%(unquoted_source_table)s" queryout %(source_table)s.csv -c -t, -T -S .\%(source_instance)s -U %(source_user)s -P %%arg_source_passwords' % dict(list(table.items()) + list(connection_args.items()))
 
 
 
 class SourceRDBMSMysql(SourceRDBMS):
     def get_copy_table_cmd(self, table, connection_args):
         if self.source_os == 'windows':
-            return 'mysqldump.exe --login-path=wb_migration_source -t --tab=. %(source_schema)s %(source_table)s --fields-terminated-by=,' % dict(table.items() + connection_args.items())
+            return 'mysqldump.exe --login-path=wb_migration_source -t --tab=. %(source_schema)s %(source_table)s --fields-terminated-by=,' % dict(list(table.items()) + list(connection_args.items()))
         else:
-            return 'MYSQL_PWD=$arg_source_password mysqldump -h127.0.0.1 -P%(source_port)s -u%(source_user)s -t  --tab=/tmp %(source_schema)s %(source_table)s --fields-terminated-by=\',\'' % dict(table.items() + connection_args.items())
+            return 'MYSQL_PWD=$arg_source_password mysqldump -h127.0.0.1 -P%(source_port)s -u%(source_user)s -t  --tab=/tmp %(source_schema)s %(source_table)s --fields-terminated-by=\',\'' % dict(list(table.items()) + list(connection_args.items()))
 
     def get_cfg_editor_cmd(self, connection_args):
         if self.source_os == 'windows':
@@ -247,15 +251,15 @@ class SourceRDBMSMysql(SourceRDBMS):
 
 class SourceRDBMSPostgresql(SourceRDBMS):
     def get_copy_table_cmd(self, table, connection_args):
-        return 'psql -U %(source_user)s -d %(source_schema)s -c "COPY %(source_table)s TO stdout DELIMITER \',\';" > %(source_table)s.csv' % dict(table.items() + connection_args.items())
+        return 'psql -U %(source_user)s -d %(source_schema)s -c "COPY %(source_table)s TO stdout DELIMITER \',\';" > %(source_table)s.csv' % dict(list(table.items()) + list(connection_args.items()))
 
 
 class SourceRDBMSSqlAnywhere(SourceRDBMS):
     def get_copy_table_cmd(self, table, connection_args):
         if self.source_os == 'windows':
-            return """dbisql.exe -c "DBN=%(source_schema)s;UID=%(source_user)s;PWD=%arg_source_password%" "SELECT * FROM %(source_table)s; OUTPUT TO '%(source_table)s.csv' FORMAT TEXT DELIMITED BY ',' QUOTE '';""" % dict(table.items() + connection_args.items())
+            return """dbisql.exe -c "DBN=%(source_schema)s;UID=%(source_user)s;PWD=%arg_source_password%" "SELECT * FROM %(source_table)s; OUTPUT TO '%(source_table)s.csv' FORMAT TEXT DELIMITED BY ',' QUOTE '';""" % dict(list(table.items()) + list(connection_args.items()))
         else:
-            return """dbisql -c "DBN=%(source_schema)s;UID=%(source_user)s;PWD=$arg_source_password" "SELECT * FROM %(source_table)s; OUTPUT TO '%(source_table)s.csv' FORMAT TEXT DELIMITED BY ',' QUOTE '';""" % dict(table.items() + connection_args.items())
+            return """dbisql -c "DBN=%(source_schema)s;UID=%(source_user)s;PWD=$arg_source_password" "SELECT * FROM %(source_table)s; OUTPUT TO '%(source_table)s.csv' FORMAT TEXT DELIMITED BY ',' QUOTE '';""" % dict(list(table.items()) + list(connection_args.items()))
 
 
 
@@ -289,7 +293,7 @@ class DataCopyScriptWindows(DataCopyScript):
         import_file_name = 'import_%s.%s' % (source_schema, import_script.get_script_ext())
         import_sql_file_name = 'import_%s.sql' % source_schema
 
-        with open(script_path, 'wb+') as f:
+        with open(script_path, 'w+') as f:
             f.write('@ECHO OFF\r\n')
             f.write('SET MYPATH=%~dp0\r\n')
             f.write('IF EXIST %%MYPATH%%%s del /F %%MYPATH%%%s\r\n' % (self.error_log_name, self.error_log_name))
@@ -412,7 +416,7 @@ class DataCopyScriptLinux(DataCopyScript):
         import_sql_file_name = 'import_%s.sql' % source_schema
     
         with open(script_path, 'w+') as f:
-            os.chmod(script_path, 0700)
+            os.chmod(script_path, 0o700)
             f.write('#!/bin/bash\n\n')
             f.write('MYPATH=`pwd`\n')
             
@@ -516,7 +520,7 @@ class DataCopyScriptDarwin(DataCopyScript):
         import_sql_file_name = 'import_%s.sql' % source_schema
     
         with open(script_path, 'w+') as f:
-            os.chmod(script_path, 0700)
+            os.chmod(script_path, 0o700)
             f.write('#!/bin/bash\n\n')
             f.write('MYPATH=`pwd`\n')
             
